v1

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// optional actionqueue.v1.MessageOptions action = 7100;
	E_Action = &file_actionqueue_v1_options_proto_extTypes[0]
)

Extension fields to descriptorpb.MessageOptions.

var File_actionqueue_v1_options_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type MessageOptions

type MessageOptions struct {

	// name is the unique workflow name (e.g., "my-entity-queue")
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// signal is the signal name to wake the workflow (e.g., "signal:start:my-entity-queue")
	Signal string `protobuf:"bytes,2,opt,name=signal,proto3" json:"signal,omitempty"`
	// workflow_id_fields are field names to compose the workflow ID.
	// Example: ["tenant_id", "entity_id"] -> "my-queue:{tenant_id}:{entity_id}"
	WorkflowIdFields []string `protobuf:"bytes,3,rep,name=workflow_id_fields,json=workflowIdFields,proto3" json:"workflow_id_fields,omitempty"`
	// tenant_id_field is the field name for tenant extraction (default: "tenant_id")
	TenantIdField string `protobuf:"bytes,4,opt,name=tenant_id_field,json=tenantIdField,proto3" json:"tenant_id_field,omitempty"`
	// contains filtered or unexported fields
}

MessageOptions marks a message as an action queue action proto and configures generation.

func (*MessageOptions) Descriptor deprecated

func (*MessageOptions) Descriptor() ([]byte, []int)

Deprecated: Use MessageOptions.ProtoReflect.Descriptor instead.

func (*MessageOptions) GetName

func (x *MessageOptions) GetName() string

func (*MessageOptions) GetSignal

func (x *MessageOptions) GetSignal() string

func (*MessageOptions) GetTenantIdField

func (x *MessageOptions) GetTenantIdField() string

func (*MessageOptions) GetWorkflowIdFields

func (x *MessageOptions) GetWorkflowIdFields() []string

func (*MessageOptions) ProtoMessage

func (*MessageOptions) ProtoMessage()

func (*MessageOptions) ProtoReflect

func (x *MessageOptions) ProtoReflect() protoreflect.Message

func (*MessageOptions) Reset

func (x *MessageOptions) Reset()

func (*MessageOptions) String

func (x *MessageOptions) String() string

Jump to